summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/timeedit.h')
-rw-r--r--kalarm/lib/timeedit.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kalarm/lib/timeedit.h b/kalarm/lib/timeedit.h
index 5888c766..9cbfb6f8 100644
--- a/kalarm/lib/timeedit.h
+++ b/kalarm/lib/timeedit.h
@@ -21,8 +21,8 @@
#ifndef TIMEEDIT_H
#define TIMEEDIT_H
-#include <qdatetime.h>
-#include <qhbox.h>
+#include <tqdatetime.h>
+#include <tqhbox.h>
class ComboBox;
class TimeSpinBox;
@@ -55,7 +55,7 @@ class TimeEdit : public QHBox
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit TimeEdit(QWidget* parent = 0, const char* name = 0);
+ explicit TimeEdit(TQWidget* parent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the widget is read-only for the user. If read-only,
@@ -74,8 +74,8 @@ class TimeEdit : public QHBox
void setValid(bool valid);
/** Returns the entered time as a value in minutes. */
int value() const;
- /** Returns the entered time as a QTime value. */
- QTime time() const { int m = value(); return QTime(m/60, m%60); }
+ /** Returns the entered time as a TQTime value. */
+ TQTime time() const { int m = value(); return TQTime(m/60, m%60); }
/** Returns true if it is possible to step the value from the highest value to the lowest value and vice versa. */
bool wrapping() const;
/** Sets whether it is possible to step the value from the highest value to the lowest value and vice versa.
@@ -86,19 +86,19 @@ class TimeEdit : public QHBox
int minValue() const;
/** Returns the maximum value of the widget in minutes. */
int maxValue() const;
- /** Returns the maximum value of the widget as a QTime value. */
- QTime maxTime() const { int mv = maxValue(); return QTime(mv/60, mv%60); }
+ /** Returns the maximum value of the widget as a TQTime value. */
+ TQTime maxTime() const { int mv = maxValue(); return TQTime(mv/60, mv%60); }
/** Sets the minimum value of the widget. */
void setMinValue(int minutes);
/** Sets the maximum value of the widget. */
void setMaxValue(int minutes);
/** Sets the maximum value of the widget. */
- void setMaxValue(const QTime& time) { setMaxValue(time.hour()*60 + time.minute()); }
+ void setMaxValue(const TQTime& time) { setMaxValue(time.hour()*60 + time.minute()); }
public slots:
/** Sets the value of the widget. */
virtual void setValue(int minutes);
/** Sets the value of the widget. */
- void setValue(const QTime& t) { setValue(t.hour()*60 + t.minute()); }
+ void setValue(const TQTime& t) { setValue(t.hour()*60 + t.minute()); }
signals:
/** This signal is emitted every time the value of the widget changes
* (for whatever reason).